jta_color_pal: Retrieve a Palette

Description Usage Arguments Details Value

Description

This function excepts a character string for a palette and returns a function that can be turned into a palette

Usage

1
jta_color_pal(palette = "logo", reverse = FALSE, ...)

Arguments

palette

A string representing a color palette, see for a full list of palettes

reverse

When true the default order of the color palette is reversed

Details

adding a number after the function call will create a palette with that number of steps

Value

a function to create a color palette


renaissanceplanning/jtacolorsr documentation built on Dec. 22, 2021, 2:59 p.m.