jta_cols: Retrieve a Color

Description Usage Details

View source: R/Colors_Dev.R

Description

This function takes a string or group of strings and returns hex codes for the corresponding colors

Usage

1

Details

A full list of the colors in this package can be returned by running the function with no input


renaissanceplanning/jtacolorsr documentation built on Dec. 22, 2021, 2:59 p.m.