scale_color_jta: Create a Color Scale for ggplot

Description Usage Arguments Details Value

Description

This function is inserted into a ggplot call to replace a scale_color command.

Usage

1
scale_color_jta(palette = "logo", discrete = TRUE, reverse = FALSE, ...)

Arguments

palette

A string representing a color palette, see https://bfroebrpg.github.io/rpgcolorsr_pages/ for a full list of palettes

discrete

Changes between discrete or continuous scales

reverse

When true the default order of the color palette is reversed

Details

By default the palette will be discrete.

Value

a function to create a color palette


renaissanceplanning/jtacolorsr documentation built on Dec. 22, 2021, 2:59 p.m.