Description Usage Arguments Details Value
This function excepts a character string for a palette and returns a function that can be turned into a palette
1 | jta_color_pal(palette = "logo", reverse = FALSE, ...)
|
palette |
A string representing a color palette, see for a full list of palettes |
reverse |
When true the default order of the color palette is reversed |
adding a number after the function call will create a palette with that number of steps
a function to create a color palette
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.